//
//  EAGLView.h
//  C3DConverterTest
//
//  Created by Rob Bajorek on 5/9/09.
//  Copyright SakariTech Inc. 2009. All rights reserved.
//


#import <UIKit/UIKit.h>
#import <OpenGLES/EAGL.h>
#import <OpenGLES/ES1/gl.h>
#import <OpenGLES/ES1/glext.h>

/*
 This class wraps the CAEAGLLayer from CoreAnimation into a convenient UIView subclass.
 The view content is basically an EAGL surface you render your OpenGL scene into.
 Note that setting the view non-opaque will only work if the EAGL surface has an alpha channel.
 */
@interface EAGLView : UIView {
  
@private
  /* The pixel dimensions of the backbuffer */
  GLint backingWidth;
  GLint backingHeight;
  
  EAGLContext *context;
  
  /* OpenGL names for the renderbuffer and framebuffers used to render to this view */
  GLuint viewRenderbuffer, viewFramebuffer;
  
  /* OpenGL name for the depth buffer that is attached to viewFramebuffer */
  GLuint depthRenderbuffer;
  
  // Stores the texture ID of our objects
  GLuint objectTextureID;
  
  // These control the max framerate of the application
  NSTimer *animationTimer;
  NSTimeInterval animationInterval;
}

@property NSTimeInterval animationInterval;

- (void)startAnimation;
- (void)stopAnimation;
- (void)setupView;          // One-time GL setup
- (void)drawView;           // Draw the objects

// Loads a texture and assigns a GL texture ID
- (void)setupObjectTexture;
- (void)setupTexture: (NSString *) texture ID: (GLuint *) textureID;

@end
